==> vtk6-6.3.0-4-armv7h.pkg.tar.xz: vtk/vtkRibbonFilter.java <==
// java wrapper for vtkRibbonFilter object
//

package vtk;
import vtk.*;

public class vtkRibbonFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetAngle_6(double id0);
  public void SetAngle(double id0)
    { SetAngle_6(id0); }

  private native double GetAngleMinValue_7();
  public double GetAngleMinValue()
    { return GetAngleMinValue_7(); }

  private native double GetAngleMaxValue_8();
  public double GetAngleMaxValue()
    { return GetAngleMaxValue_8(); }

  private native double GetAngle_9();
  public double GetAngle()
    { return GetAngle_9(); }

  private native void SetVaryWidth_10(int id0);
  public void SetVaryWidth(int id0)
    { SetVaryWidth_10(id0); }

  private native int GetVaryWidth_11();
  public int GetVaryWidth()
    { return GetVaryWidth_11(); }

  private native void VaryWidthOn_12();
  public void VaryWidthOn()
    { VaryWidthOn_12(); }

  private native void VaryWidthOff_13();
  public void VaryWidthOff()
    { VaryWidthOff_13(); }

  private native void SetWidthFactor_14(double id0);
  public void SetWidthFactor(double id0)
    { SetWidthFactor_14(id0); }

  private native double GetWidthFactor_15();
  public double GetWidthFactor()
    { return GetWidthFactor_15(); }

  private native void SetDefaultNormal_16(double id0,double id1,double id2);
  public void SetDefaultNormal(double id0,double id1,double id2)
    { SetDefaultNormal_16(id0,id1,id2); }

  private native void SetDefaultNormal_17(double id0[]);
  public void SetDefaultNormal(double id0[])
    { SetDefaultNormal_17(id0); }

  private native double[] GetDefaultNormal_18();
  public double[] GetDefaultNormal()
    { return GetDefaultNormal_18(); }

  private native void SetUseDefaultNormal_19(int id0);
  public void SetUseDefaultNormal(int id0)
    { SetUseDefaultNormal_19(id0); }

  private native int GetUseDefaultNormal_20();
  public int GetUseDefaultNormal()
    { return GetUseDefaultNormal_20(); }

  private native void UseDefaultNormalOn_21();
  public void UseDefaultNormalOn()
    { UseDefaultNormalOn_21(); }

  private native void UseDefaultNormalOff_22();
  public void UseDefaultNormalOff()
    { UseDefaultNormalOff_22(); }

  private native void SetGenerateTCoords_23(int id0);
  public void SetGenerateTCoords(int id0)
    { SetGenerateTCoords_23(id0); }

  private native int GetGenerateTCoordsMinValue_24();
  public int GetGenerateTCoordsMinValue()
    { return GetGenerateTCoordsMinValue_24(); }

  private native int GetGenerateTCoordsMaxValue_25();
  public int GetGenerateTCoordsMaxValue()
    { return GetGenerateTCoordsMaxValue_25(); }

  private native int GetGenerateTCoords_26();
  public int GetGenerateTCoords()
    { return GetGenerateTCoords_26(); }

  private native void SetGenerateTCoordsToOff_27();
  public void SetGenerateTCoordsToOff()
    { SetGenerateTCoordsToOff_27(); }

  private native void SetGenerateTCoordsToNormalizedLength_28();
  public void SetGenerateTCoordsToNormalizedLength()
    { SetGenerateTCoordsToNormalizedLength_28(); }

  private native void SetGenerateTCoordsToUseLength_29();
  public void SetGenerateTCoordsToUseLength()
    { SetGenerateTCoordsToUseLength_29(); }

  private native void SetGenerateTCoordsToUseScalars_30();
  public void SetGenerateTCoordsToUseScalars()
    { SetGenerateTCoordsToUseScalars_30(); }

  private native String GetGenerateTCoordsAsString_31();
  public String GetGenerateTCoordsAsString()
    { return GetGenerateTCoordsAsString_31(); }

  private native void SetTextureLength_32(double id0);
  public void SetTextureLength(double id0)
    { SetTextureLength_32(id0); }

  private native double GetTextureLengthMinValue_33();
  public double GetTextureLengthMinValue()
    { return GetTextureLengthMinValue_33(); }

  private native double GetTextureLengthMaxValue_34();
  public double GetTextureLengthMaxValue()
    { return GetTextureLengthMaxValue_34(); }

  private native double GetTextureLength_35();
  public double GetTextureLength()
    { return GetTextureLength_35(); }

  public vtkRibbonFilter() { super(); }

  public vtkRibbonFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkRibbonFilter.java <==
// java wrapper for vtkRibbonFilter object
//

package vtk;
import vtk.*;

public class vtkRibbonFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetAngle_6(double id0);
  public void SetAngle(double id0)
    { SetAngle_6(id0); }

  private native double GetAngleMinValue_7();
  public double GetAngleMinValue()
    { return GetAngleMinValue_7(); }

  private native double GetAngleMaxValue_8();
  public double GetAngleMaxValue()
    { return GetAngleMaxValue_8(); }

  private native double GetAngle_9();
  public double GetAngle()
    { return GetAngle_9(); }

  private native void SetVaryWidth_10(int id0);
  public void SetVaryWidth(int id0)
    { SetVaryWidth_10(id0); }

  private native int GetVaryWidth_11();
  public int GetVaryWidth()
    { return GetVaryWidth_11(); }

  private native void VaryWidthOn_12();
  public void VaryWidthOn()
    { VaryWidthOn_12(); }

  private native void VaryWidthOff_13();
  public void VaryWidthOff()
    { VaryWidthOff_13(); }

  private native void SetWidthFactor_14(double id0);
  public void SetWidthFactor(double id0)
    { SetWidthFactor_14(id0); }

  private native double GetWidthFactor_15();
  public double GetWidthFactor()
    { return GetWidthFactor_15(); }

  private native void SetDefaultNormal_16(double id0,double id1,double id2);
  public void SetDefaultNormal(double id0,double id1,double id2)
    { SetDefaultNormal_16(id0,id1,id2); }

  private native void SetDefaultNormal_17(double id0[]);
  public void SetDefaultNormal(double id0[])
    { SetDefaultNormal_17(id0); }

  private native double[] GetDefaultNormal_18();
  public double[] GetDefaultNormal()
    { return GetDefaultNormal_18(); }

  private native void SetUseDefaultNormal_19(int id0);
  public void SetUseDefaultNormal(int id0)
    { SetUseDefaultNormal_19(id0); }

  private native int GetUseDefaultNormal_20();
  public int GetUseDefaultNormal()
    { return GetUseDefaultNormal_20(); }

  private native void UseDefaultNormalOn_21();
  public void UseDefaultNormalOn()
    { UseDefaultNormalOn_21(); }

  private native void UseDefaultNormalOff_22();
  public void UseDefaultNormalOff()
    { UseDefaultNormalOff_22(); }

  private native void SetGenerateTCoords_23(int id0);
  public void SetGenerateTCoords(int id0)
    { SetGenerateTCoords_23(id0); }

  private native int GetGenerateTCoordsMinValue_24();
  public int GetGenerateTCoordsMinValue()
    { return GetGenerateTCoordsMinValue_24(); }

  private native int GetGenerateTCoordsMaxValue_25();
  public int GetGenerateTCoordsMaxValue()
    { return GetGenerateTCoordsMaxValue_25(); }

  private native int GetGenerateTCoords_26();
  public int GetGenerateTCoords()
    { return GetGenerateTCoords_26(); }

  private native void SetGenerateTCoordsToOff_27();
  public void SetGenerateTCoordsToOff()
    { SetGenerateTCoordsToOff_27(); }

  private native void SetGenerateTCoordsToNormalizedLength_28();
  public void SetGenerateTCoordsToNormalizedLength()
    { SetGenerateTCoordsToNormalizedLength_28(); }

  private native void SetGenerateTCoordsToUseLength_29();
  public void SetGenerateTCoordsToUseLength()
    { SetGenerateTCoordsToUseLength_29(); }

  private native void SetGenerateTCoordsToUseScalars_30();
  public void SetGenerateTCoordsToUseScalars()
    { SetGenerateTCoordsToUseScalars_30(); }

  private native String GetGenerateTCoordsAsString_31();
  public String GetGenerateTCoordsAsString()
    { return GetGenerateTCoordsAsString_31(); }

  private native void SetTextureLength_32(double id0);
  public void SetTextureLength(double id0)
    { SetTextureLength_32(id0); }

  private native double GetTextureLengthMinValue_33();
  public double GetTextureLengthMinValue()
    { return GetTextureLengthMinValue_33(); }

  private native double GetTextureLengthMaxValue_34();
  public double GetTextureLengthMaxValue()
    { return GetTextureLengthMaxValue_34(); }

  private native double GetTextureLength_35();
  public double GetTextureLength()
    { return GetTextureLength_35(); }

  public vtkRibbonFilter() { super(); }

  public vtkRibbonFilter(long id) { super(id); }
  public native long   VTKInit();

}
